==> jmb.payment-0.2.tar.gz: jmb.payment-0.2/jmb/payment/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext as _

from jmb.core.admin.options import ExtendibleModelAdmin
from jmb.payment.models import PaymentForm, PaymentInstallment

class PaymentInstallmentInline(admin.TabularInline):
    model = PaymentInstallment
    extra = 0
    fk_name = 'payment_form'
    fields = (
        'amount', 'days', 'end_month',
        'days_end_month', 'discount', 'fee'
    )

class PaymentFormAdmin(ExtendibleModelAdmin):
    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}
    advanced_search_fields = (('status__in', 'code__istartswith', 'name__istartswith'),)
    fieldsets = (
        (_('logs admin'), {'fields':
                               (('creator', 'date_create',), ('last_modifier', 'date_last_modify',)
                                   ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', ('code', 'name'), 'description', ('fee', 'discount'))}),
        )
    search_fields = ['name']
    list_display = (
        'get_status_icon', 'get_object_error', 'name', 'fee', 'discount',
        'get_edit_icon', 'get_delete_icon'
        )
    list_display_csv = ('status', 'code', 'name')
    inlines = [PaymentInstallmentInline,]

    def get_object_error(self, result):
        ## per bordare di rosso i pagamenti con rate errate
        code = result.code
        tot_amount = 0
        for installment in result.installments.all():
            tot_amount += installment.amount
        if tot_amount != 100:
            code = "<span class='object_error'>%s</span>" % result.code
        return code
    get_object_error.allow_tags = True
    get_object_error.short_description = _("Code")

class PaymentInstallmentAdmin(ExtendibleModelAdmin):
    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}

    advanced_search_fields = (('status__in', 'code__istartswith', 'name__istartswith'),)
    fieldsets = (
        (_('logs admin'), {'fields': (
            ('creator', 'date_create',),
            ('last_modifier', 'date_last_modify',)
            ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': (
            'status', ('code', 'name'),
            'description', 'payment_form',
            ('amount', 'days',),
            ('end_month', 'days_end_month',),
            ('fee', 'discount'),
        ),},),
    )
    list_display = (
        'get_status_icon', 'payment_form', 'code', 'name', 'amount', 'days', 'end_month',
        'days_end_month', 'get_edit_icon', 'get_delete_icon'
        )
    list_display_csv = (
        'status', 'code', 'name', 'amount', 'days',
        'end_month', 'days_end_month'
        )
    ordering = ['ordering', 'code']

admin.site.register(PaymentForm, PaymentFormAdmin)
admin.site.register(PaymentInstallment, PaymentInstallmentAdmin)

==> jmb.payment-0.4.tar.gz: jmb.payment-0.4/jmb/payment/admin.py <==
# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from jmb.jadmin.options import JumboModelAdmin
from jmb.payment.models import PaymentForm, PaymentInstallment


class PaymentInstallmentInline(admin.TabularInline):
    model = PaymentInstallment
    extra = 0
    fk_name = 'payment_form'
    fields = (
        'amount', 'days', 'end_month',
        'days_end_month', 'discount', 'fee'
    )


class PaymentFormAdmin(JumboModelAdmin):

    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}
    advanced_search_fields = (('status__in', 'code__istartswith', 'name__istartswith'),)
    fieldsets = (
        (_('logs admin'), {'fields': (
            ('creator', 'date_create',), ('last_modifier', 'date_last_modify',)
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',)}),
        (_('general admin'), {
         'fields': ('status', ('code', 'name'), 'description', ('fee', 'discount'))}),
    )
    search_fields = ['name']
    list_display = (
        'get_status_icon', 'get_object_error', 'name', 'fee', 'discount',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = ('status', 'code', 'name')
    inlines = [PaymentInstallmentInline]

    def get_object_error(self, result):
        ## per bordare di rosso i pagamenti con rate errate
        code = result.code
        tot_amount = 0
        for installment in result.installments.all():
            tot_amount += installment.amount
        if tot_amount != 100:
            code = "<span class='object_error'>%s</span>" % result.code
        return code
    get_object_error.allow_tags = True
    get_object_error.short_description = _("Code")


class PaymentInstallmentAdmin(JumboModelAdmin):

    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}

    advanced_search_fields = (('status__in', 'code__istartswith', 'name__istartswith'),)
    fieldsets = (
        (_('logs admin'), {'fields': (
            ('creator', 'date_create',),
            ('last_modifier', 'date_last_modify',)
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',)}),
        (_('general admin'), {'fields': (
            'status', ('code', 'name'),
            'description', 'payment_form',
            ('amount', 'days',),
            ('end_month', 'days_end_month',),
            ('fee', 'discount'),
        )},),
    )
    list_display = (
        'get_status_icon', 'payment_form', 'code', 'name', 'amount', 'days', 'end_month',
        'days_end_month', 'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'status', 'code', 'name', 'amount', 'days',
        'end_month', 'days_end_month'
    )
    ordering = ['ordering', 'code']

admin.site.register(PaymentForm, PaymentFormAdmin)
admin.site.register(PaymentInstallment, PaymentInstallmentAdmin)
